@@ -1,6 +1,5 @@
 #!perl -w
 # $Id: TCP-talk-to-ourself.pl 29 2008-10-11 15:19:36Z sanko@cpan.org $
-# Stolen from libwww-perl
 use strict;
 use warnings;
 require IO::Socket;
@@ -46,3 +45,35 @@ else {
 exit if close(CLIENT);
 die qq[Can't wait for client: $!] if $!;
 die qq[The can-we-talk-to-ourself test failed.\n];
+
+=head1 Notes
+
+This was stolen from libwww-perl.
+
+=head1 Author
+
+Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
+
+CPAN ID: SANKO
+
+=head1 License and Legal
+
+Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of The Artistic License 2.0.  See the F<LICENSE>
+file included with this distribution or
+http://www.perlfoundation.org/artistic_license_2_0.  For
+clarification, see http://www.perlfoundation.org/artistic_2_0_notes.
+
+When separated from the distribution, all POD documentation is covered
+by the Creative Commons Attribution-Share Alike 3.0 License.  See
+http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
+clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
+
+Neither this module nor the L<Author|/Author> is affiliated with
+BitTorrent, Inc.
+
+=for svn $Id$
+
+=cut
